#############################################################################
# Script to compute work of forces and to plot results of MD simulation     #
# V.A. Yastrebov (MINES ParisTech, CNRS), Feb 2020-2022.                    #
#                                                                           #
# Licence: CC0                                                              #
#############################################################################

import sys
import numpy as np

import matplotlib.pyplot as plt
import matplotlib
#matplotlib.rcParams['text.usetex'] = True
#matplotlib.rcParams['text.latex.unicode'] = True
#matplotlib.rcParams['figure.figsize'] = 12, 10
#matplotlib.rcParams.update({'font.size': 20})

if len(sys.argv) != 4:
  print("I need 3 arguments: [1] filename, [2] displacement column, [3] force column.\n")
#  exit(1)

filename = sys.argv[1]
outfilename  = "force_displacement_"+filename.strip().split(".")[0]+".data"
ui = int(sys.argv[2])
fi = int(sys.argv[3])

start_reading = False
out = open(outfilename,"w")
inf = open(filename,"r")
for l in inf.readlines():
  if start_reading:
    if l[:4] == "Loop":
        break
    out.write(l)
  if l[:4] == "Step":
    out.write("# "+l)
    start_reading = True
inf.close()
out.close()

u,f = np.loadtxt(outfilename,usecols=(ui-1,fi-1),unpack=True)

du = u[1:-1].copy() - u[0:-2].copy() 
faverage = 0.5*(f[0:-2].copy() + f[1:-1].copy())


def H(x):
    if x < 0:
       return 0.
    else:
       return 1.
Heaviside = np.vectorize(H)

integral = np.dot(du,faverage*Heaviside(faverage))
print("Integral = "+str(integral))


fig,ax = plt.subplots()
plt.grid(True)
plt.xlabel("Displacement (L.U.)")
plt.ylabel("Force (F.U.)")
plt.xlim([0,np.max(u)-u[0]+du[0]])
#print("du="+str(du[0]))
plt.ylim([0,1.1*np.max(f)]) 
plt.plot(u-u[0]+du[0],f,"o-",color = "k")
xloc = np.min(u) + 0.8*(np.max(u)-np.min(u))
yloc = np.min(f) + 0.9*(np.max(f)-np.min(f))
plt.text(xloc,yloc,"Toughness = {0:2.5f} (E.U.)".format(integral),size=20,ha="center",va="center",bbox=dict(boxstyle="round",ec=(1., 0.5, 0.5),fc=(1., 0.8, 0.8),))
fig.savefig("Force_displacement.png")
plt.show()


